float4x4 matWorldViewProj;
float4x4 matWorld;

texture entSkin1;

sampler2D smpDiffuse = sampler_state
{
	Texture = <entSkin1>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

struct VS_IN
{
	float4 Pos : POSITION;
	float3 Normal : NORMAL;
	float2 Tex : TEXCOORD0;
};

struct VS_OUT
{
	float4 Pos : POSITION;
	float2 Tex : TEXCOORD0;
	float3 WorldPos : TEXCOORD1;
	float3 Normal : TEXCOORD2;
};

struct PS_IN
{
	float2 Tex : TEXCOORD0;
	float3 WorldPos : TEXCOORD1;
	float3 Normal : TEXCOORD2;
};

struct PS_OUT
{
	float4 Color : COLOR0;
	float4 WorldPos : COLOR1;
	float4 Normal : COLOR2;
};

VS_OUT VertexShader(VS_IN In)
{
	VS_OUT Out = (VS_OUT)0;
	
	Out.Pos = mul(In.Pos, matWorldViewProj);
	Out.Tex = In.Tex;
	Out.WorldPos = mul(In.Pos, matWorld).xyz;
	Out.Normal = mul(In.Normal, matWorld);
	
	return Out;
}

PS_OUT PixelShader(PS_IN In)
{
	PS_OUT Out = (PS_OUT)0;
	
	Out.Color = tex2D(smpDiffuse, In.Tex);
	clip(Out.Color.a-0.5);
	Out.Color.a = 0.0;
	Out.WorldPos = float4(In.WorldPos, 0.0);
	Out.Normal = float4(In.Normal, 0.0);
	
	return Out;
}

technique t0
{
	pass p0
	{
		AlphaBlendEnable = False;
		ZWriteEnable = True;
		
		VertexShader = compile vs_3_0 VertexShader();
		PixelShader = compile ps_3_0 PixelShader();
	}
}