float4x4 matWorldViewProj;
float4x4 matWorld;

float3x3 matTangent;

float4 vecSkill41;

texture entSkin1;
texture entSkin2;

sampler2D smpDiffHeight = sampler_state
{
	Texture = <entSkin1>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

sampler2D smpNmSpec = sampler_state
{
	Texture = <entSkin2>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

struct VS_IN
{
	float4 Pos : POSITION;
	float3 Normal : NORMAL;
	float2 Tex : TEXCOORD0;
	float3 Tangent : TEXCOORD2;
};

struct VS_OUT
{
	float4 Pos : POSITION;
	float2 Tex : TEXCOORD0;
	float3 WorldPos : TEXCOORD1;
	float3 tangent0 : TEXCOORD2;
	float3 tangent1 : TEXCOORD3;
	float3 tangent2 : TEXCOORD4;
};

struct PS_IN
{
	float2 Tex : TEXCOORD0;
	float3 WorldPos : TEXCOORD1;
	float3 tangent0 : TEXCOORD2;
	float3 tangent1 : TEXCOORD3;
	float3 tangent2 : TEXCOORD4;
};

struct PS_OUT
{
	float4 Color : COLOR0;
	float4 WorldPos : COLOR1;
	float4 Normal : COLOR2;
};

VS_OUT VertexShader(VS_IN In)
{
	VS_OUT Out = (VS_OUT)0;
	
	Out.tangent0 = mul(In.Tangent, matWorld);
	Out.tangent1 = mul(cross(In.Tangent, In.Normal), matWorld);
	Out.tangent2 = mul(In.Normal, matWorld);
	
	Out.Pos = mul(In.Pos, matWorldViewProj);
	Out.Tex = In.Tex;
	Out.WorldPos = mul(In.Pos, matWorld).xyz;
	
	return Out;
}

PS_OUT PixelShader(PS_IN In)
{
	PS_OUT Out = (PS_OUT)0;
	
	matTangent[0] = In.tangent0;
	matTangent[1] = In.tangent1;
	matTangent[2] = In.tangent2;
	
	float4 Normal = tex2D(smpNmSpec, In.Tex);
	Normal.xyz = Normal.xyz*2.0-1.0;
	Normal.y *= -1;
	Normal.xyz = normalize(mul(Normal.xyz, matTangent));
	
	Out.Color = tex2D(smpDiffHeight, In.Tex);
	Out.Color.a = Normal.w*vecSkill41.y;
	Out.WorldPos = float4(In.WorldPos,vecSkill41.x);
	Out.Normal = float4(Normal.xyz*0.5+0.5, 0.0);
	
	return Out;
}

technique t0
{
	pass p0
	{
		AlphaBlendEnable = False;
		ZWriteEnable = True;
		
		VertexShader = compile vs_3_0 VertexShader();
		PixelShader = compile ps_3_0 PixelShader();
	}
}