#define DL_MAX_LIGHTS 25

float4 DL_LightPos_flt[DL_MAX_LIGHTS];
float4 DL_LightColor_flt[DL_MAX_LIGHTS];

float3 vecViewPos;

texture mtlSkin1;
texture mtlSkin2;
texture mtlSkin3;
texture mtlSkin4;

sampler2D smpCol0 = sampler_state
{
	texture = <mtlSkin1>;
};

sampler2D smpCol1 = sampler_state
{
	texture = <mtlSkin2>;
};

sampler2D smpCol2 = sampler_state
{
	texture = <mtlSkin3>;
};

sampler2D smpCol3 = sampler_state
{
	texture = <mtlSkin4>;
};

float4 PixelShader( float2 Tex : TEXCOORD0 ) : COLOR0 
{
	float4 Color = tex2D(smpCol0, Tex);
	float4 Pos = tex2D(smpCol1, Tex);
	float4 Normal = tex2D(smpCol2, Tex);
	Normal.xyz = Normal.xyz*2.0-1.0;
	Normal.xyz = normalize(Normal.xyz);
	
	float3 lightdir;
	float3 viewdir;
	float3 halfvec;
	float att;
	float diffuse;
	float3 shading = Normal.w;
	float3 specularity = 0.0;
	
	for(int i = 0; i < DL_MAX_LIGHTS; i++)
	{
		lightdir = (DL_LightPos_flt[i].xyz-Pos.xyz)/DL_LightPos_flt[i].w;
		att = saturate(1.0-dot(lightdir, lightdir));
		lightdir = normalize(lightdir);
		diffuse = saturate(dot(Normal, lightdir));
		
		shading += DL_LightColor_flt[i]*diffuse*att;
		
		viewdir = normalize(vecViewPos.xyz-Pos.xyz);
		halfvec = normalize(viewdir+lightdir);
		specularity += DL_LightColor_flt[i]*pow(saturate(dot(halfvec, Normal)), Pos.w)*diffuse*Color.w;
	}
	
	Color.rgb *= shading;
	Color.rgb += specularity;
	
	return Color;
}

technique blackout
{
	pass one
	{
		PixelShader = compile ps_3_0 PixelShader();
	}
}